This module is generated by the #[sabi_trait] attribute on Function
Structs
- Function_
Interface - A marker type describing the traits that are required when constructing
Function_TO,and are then implemented by it, by implementing theInterfaceTypetrait. - Function_
TO - The trait object for Function.
Traits
- Function
- A loaded function instance. Constructed once per library via
FunctionMod::new_functionsand reused across requests, so it must beSend + Sync.
Type Aliases
- Function_
Backend - An alias for the underlying implementation of
Function_TO. - Function_
CTO - A type alias for the const-constructible
Function_TO.